/* valaccodelabel.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaccodelabel.h"
#include <ccode/valaccodelabel.h>

struct _ValaCCodeLabelPrivate {
	char* _name;
};
#define VALA_CCODE_LABEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_LABEL, ValaCCodeLabelPrivate))
enum  {
	VALA_CCODE_LABEL_DUMMY_PROPERTY,
	VALA_CCODE_LABEL_NAME
};
static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_label_parent_class = NULL;
static void vala_ccode_label_dispose (GObject * obj);


ValaCCodeLabel* vala_ccode_label_new (const char* name)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeLabel * self;
	g_return_val_if_fail (name != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_LABEL, __params_it - __params, __params);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeLabel * self;
	self = ((ValaCCodeLabel*) base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_indent (writer);
	vala_ccode_writer_write_string (writer, vala_ccode_label_get_name (self));
	vala_ccode_writer_write_string (writer, ":");
	vala_ccode_writer_write_newline (writer);
}


char* vala_ccode_label_get_name (ValaCCodeLabel* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_LABEL (self), NULL);
	return self->priv->_name;
}


void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value)
{
	char* __temp1;
	g_return_if_fail (VALA_IS_CCODE_LABEL (self));
	__temp1 = NULL;
	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
}


static void vala_ccode_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeLabel * self;
	self = VALA_CCODE_LABEL (object);
	switch (property_id) {
		case VALA_CCODE_LABEL_NAME:
		g_value_set_string (value, vala_ccode_label_get_name (self));
		break;
	}
}


static void vala_ccode_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeLabel * self;
	self = VALA_CCODE_LABEL (object);
	switch (property_id) {
		case VALA_CCODE_LABEL_NAME:
		vala_ccode_label_set_name (self, g_value_get_string (value));
		break;
	}
}


static void vala_ccode_label_class_init (ValaCCodeLabelClass * klass)
{
	vala_ccode_label_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeLabelPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_label_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_label_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_label_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_label_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_LABEL_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_label_init (ValaCCodeLabel * self)
{
	self->priv = VALA_CCODE_LABEL_GET_PRIVATE (self);
}


static void vala_ccode_label_dispose (GObject * obj)
{
	ValaCCodeLabel * self;
	ValaCCodeLabelClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_LABEL (obj);
	(self->priv->_name = (g_free (self->priv->_name), NULL));
	klass = VALA_CCODE_LABEL_CLASS (g_type_class_peek (VALA_TYPE_CCODE_LABEL));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_label_get_type (void)
{
	static GType vala_ccode_label_type_id = 0;
	if (G_UNLIKELY (vala_ccode_label_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLabel), 0, (GInstanceInitFunc) vala_ccode_label_init };
		vala_ccode_label_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeLabel", &g_define_type_info, 0);
	}
	return vala_ccode_label_type_id;
}




